@@ -1,4 +1,4 @@
-#!/usr/bin/env gjs
+#!/usr/bin/env -S gjs -m
 
 /* -*- Mode: JS2; indent-tabs-mode: nil; js2-basic-offset: 4 -*- */
 /* vim: set et ts=4 sw=4: */
@@ -29,34 +29,31 @@
  *
  */
 
-const Gio = imports.gi.Gio;
+import Gio from 'gi://Gio';
 
-const ByteArray = imports.byteArray;
-
-const PRESETS_PATH = 'data/presets/presets';
-const LOCALES_PATH = 'dist/locales';
-const PRESET_TYPES = [ 'aeroway',
+const PRESETS_PATH = 'data/presets';
+const LOCALES_PATH = 'dist/translations';
+const PRESET_TYPES = [ 'aerialway',
+                       'aeroway',
                        'amenity',
+                       'barrier',
+                       'highway',
+                       'historic',
                        'leisure',
                        'office',
                        'place',
+                       'railway',
                        'shop',
                        'tourism' ];
 
 const OUTPUT = {};
 
-function getBufferText(buffer) {
-    if (buffer instanceof Uint8Array) {
-        return ByteArray.toString(buffer);
-    } else {
-        return buffer.toString();
-    }
-}
+let decoder = new TextDecoder('utf-8');
 
 function parseJson(dirPath, fileName) {
     let file = Gio.File.new_for_path(dirPath + '/' + fileName);
     let [status, buffer] = file.load_contents(null);
-    let {tags, name} = JSON.parse(getBufferText(buffer));
+    let {tags, name} = JSON.parse(decoder.decode(buffer));
 
     for (let key in tags) {
         let value = tags[key];
@@ -92,7 +89,7 @@ function processTypes(basePath) {
 function processLocale(dirPath, fileName) {
     let file = Gio.File.new_for_path(dirPath + '/' + fileName);
     let [status, buffer] = file.load_contents(null);
-    let object = JSON.parse(getBufferText(buffer));
+    let object = JSON.parse(decoder.decode(buffer));
     let lang = fileName.substring(0, fileName.indexOf('.json'));
 
     for (let type in OUTPUT) {
