@@ -31,7 +31,6 @@ import {Geoclue} from './geoclue.js';
 import * as GeocodeFactory from './geocode.js';
 import {MainWindow} from './mainWindow.js';
 import {OSMEdit} from './osmEdit.js';
-import {OSMTypeSearchEntry} from './osmTypeSearchEntry.js';
 import {PlaceStore} from './placeStore.js';
 import {RoutingDelegator} from './routingDelegator.js';
 import {RouteQuery} from './routeQuery.js';
@@ -42,8 +41,6 @@ import { Place } from './place.js';
 
 const Format = imports.format;
 
-const _ensuredTypes = [OSMTypeSearchEntry];
-
 export class Application extends Adw.Application {
 
     // used globally
@@ -64,9 +61,6 @@ export class Application extends Adw.Application {
         GLib.set_application_name(_("Maps"));
         Gtk.Window.set_default_icon_name(pkg.name);
 
-        /* Needed to be able to use in UI files */
-        _ensuredTypes.forEach((type) => GObject.type_ensure(type));
-
         super({ application_id: pkg.name,
                 flags: Gio.ApplicationFlags.HANDLES_OPEN |
                        Gio.ApplicationFlags.HANDLES_COMMAND_LINE,
@@ -107,6 +101,10 @@ export class Application extends Adw.Application {
                              _("[FILE…|URI]"));
     }
 
+    get mainWindow() {
+        return this._mainWindow;
+    }
+
     _onOsmAccountSetupActivate() {
         let dialog =
             Application.osmEdit.createAccountDialog(false);
@@ -252,8 +250,8 @@ export class Application extends Adw.Application {
             if (error) {
                 this._mainWindow.showToast(_("An error has occurred"));
             } else {
-                // clear search entry
-                this._mainWindow.searchBar.text = '';
+                // fill in search entry with query string
+                this._mainWindow.searchBar.setTextWithoutTriggeringSearch(query);
 
                 if (places) {
                     /* if there's only one place in results, show it directly
