@@ -24,32 +24,31 @@ import 'gi://Adw?version=1';
 import 'gi://GeocodeGlib?version=2.0';
 import 'gi://Gdk?version=4.0';
 import 'gi://GdkPixbuf?version=2.0';
-import 'gi://Gio?version=2.0';
-import 'gi://GLib?version=2.0';
+import Gio from 'gi://Gio?version=2.0';
+import GLib from 'gi://GLib?version=2.0';
 import 'gi://GObject?version=2.0';
 import 'gi://Gtk?version=4.0';
 import 'gi://GWeather?version=4.0';
 import 'gi://Rest?version=1.0';
 import 'gi://Shumate?version=1.0';
 import 'gi://Soup?version=3.0';
+import 'gi://Xdp?version=1.0';
 
 import * as system from 'system';
 
 import {Application} from './application.js';
+import './prototypes.js';
 
 pkg.initGettext();
 pkg.initFormat();
 
+Gio.Resource.load(GLib.build_filenamev([pkg.pkgdatadir, `${pkg.name}.shields.gresource`]))._register();
+
 function main(args) {
     /* Add prototype to get last element of an array.
      * TODO: if we get more of these, might move initing
      * to a decicated Prototypes modules.
      */
-    if (!Array.prototype.last) {
-        Array.prototype.last = function() {
-            return this[this.length - 1];
-        }
-    }
 
     let application = new Application();
     return application.run(args);
