@@ -28,13 +28,13 @@
  */
 
 import GLib from 'gi://GLib';
-import Shumate from 'gi://Shumate';
 import Soup from 'gi://Soup';
 
 import {Application} from '../application.js';
 import * as GraphHopperTransit from '../graphHopperTransit.js';
 import * as HVT from '../hvt.js';
 import {Query} from '../http.js';
+import * as Time from '../time.js';
 import {Itinerary, Leg, RouteType, Stop} from '../transitPlan.js';
 import * as Utils from '../utils.js';
 
@@ -233,8 +233,8 @@ export class OpendataCH {
             connection.to.arrivalTimestamp - connection.from.departureTimestamp;
         let from = connection.from;
         let to = connection.to;
-        let [startTime,] = this._parseTime(from.departure);
-        let [endTime,] = this._parseTime(to.arrival);
+        let [startTime,] = Time.parseTime(from.departure);
+        let [endTime,] = Time.parseTime(to.arrival);
 
         return new Itinerary({ duration:  duration,
                                departure: startTime,
@@ -242,17 +242,6 @@ export class OpendataCH {
                                legs:      legs });
     }
 
-    /**
-     * Parse a time string into an array with
-     * an absolute timestamp in ms since Unix epoch and a timezone offset
-     * for the provider's native timezone at the given time and date
-     */
-    _parseTime(timeString) {
-        let dateTime = GLib.DateTime.new_from_iso8601(timeString, null);
-
-        return [dateTime.to_unix() * 1000, dateTime.get_utc_offset() / 1000];
-    }
-
     _createLegs(sections) {
         let result = sections.map((section, index, sections) =>
                                     this._createLeg(section, index, sections));
@@ -285,40 +274,36 @@ export class OpendataCH {
         let to =
             last && !journey ? this._query.filledPoints.last().place.name :
                                arrival.station.nam;
-        let [departureTime, tzOffset] = this._parseTime(departure.departure);
-        let [arrivalTime,] = this._parseTime(arrival.arrival);
+        let [departureTime, tzOffset] = Time.parseTime(departure.departure);
+        let [arrivalTime,] = Time.parseTime(arrival.arrival);
         let route = journey ? journey.number : null;
         let routeType =
             journey ? this._getHVTCodeFromCategory(journey.category) : null;
         let agencyName = journey ? journey.operator : null;
-        let polyline = this._createPolylineForSection(section, index, sections);
         let duration = arrival.arrivalTimestamp - departure.departureTimestamp;
         let headsign = journey ? journey.to : null;
         let [departureX, departureY, arrivalX, arrivalY] =
             this._getCoordsForSection(section, index, sections);
+        let intermediateStops =
+            journey ? this._createIntermediateStops(journey) : null;
 
-        let result = new Leg({ departure:            departureTime,
-                               arrival:              arrivalTime,
-                               from:                 from,
-                               to:                   to,
-                               headsign:             headsign,
-                               fromCoordinate:       [departureX,
-                                                      departureY],
-                               toCoordinate:         [arrivalX,
-                                                      arrivalY],
-                               route:                route,
-                               routeType:            routeType,
-                               polyline:             polyline,
-                               isTransit:            isTransit,
-                               duration:             duration,
-                               agencyName:           agencyName,
-                               agencyTimezoneOffset: tzOffset,
-                               tripShortName:        route });
-
-        if (journey)
-            result.intermediateStops = this._createIntermediateStops(journey);
-
-        return result;
+        return new Leg({ departure:            departureTime,
+                         arrival:              arrivalTime,
+                         from:                 from,
+                         to:                   to,
+                         headsign:             headsign,
+                         fromCoordinate:       [departureX,
+                                                departureY],
+                         toCoordinate:         [arrivalX,
+                                                arrivalY],
+                         route:                route,
+                         routeType:            routeType,
+                         isTransit:            isTransit,
+                         duration:             duration,
+                         agencyName:           agencyName,
+                         agencyTimezoneOffset: tzOffset,
+                         tripShortName:        route,
+                         intermediateStops:    intermediateStops });
     }
 
     _getHVTCodeFromCategory(category) {
@@ -386,31 +371,6 @@ export class OpendataCH {
         return [departureX, departureY, arrivalX, arrivalY];
     }
 
-    _createPolylineForSection(section, index, sections) {
-        let polyline;
-
-        if (section.journey) {
-            polyline = [];
-
-            section.journey.passList.forEach((pass) => {
-                let coordinate = pass.location.coordinate;
-                polyline.push(new Shumate.Coordinate({ latitude:  coordinate.x,
-                                                       longitude: coordinate.y }));
-            });
-        } else {
-            let [departureX, departureY, arrivalX, arrivalY] =
-                this._getCoordsForSection(section, index, sections);
-
-            polyline =
-                [new Shumate.Coordinate({ latitude:  departureX,
-                                          longitude: departureY }),
-                 new Shumate.Coordinate({ latitude:  arrivalX,
-                                          longitude: arrivalY })];
-        }
-
-        return polyline;
-    }
-
     _createIntermediateStops(journey) {
         let result = [];
 
@@ -427,9 +387,9 @@ export class OpendataCH {
         let [arrival, arrivalTzOffset] = [,];
 
         if (pass.departure)
-            [departure, departureTzOffset] = this._parseTime(pass.departure)
+            [departure, departureTzOffset] = Time.parseTime(pass.departure);
         if (pass.arrival)
-            [arrival, arrivalTzOffset] = this._parseTime(pass.arrival);
+            [arrival, arrivalTzOffset] = Time.parseTime(pass.arrival);
 
         if (!arrival)
             arrival = departure;
