@@ -24,12 +24,12 @@ import GObject from 'gi://GObject';
 
 import {Application} from './application.js';
 import * as Color from './color.js';
+import {IconMarker} from './iconMarker.js';
 import {Location} from './location.js';
-import {MapMarker} from './mapMarker.js';
 import {Place} from './place.js';
 import * as Utils from './utils.js';
 
-export class TurnPointMarker extends MapMarker {
+export class TurnPointMarker extends IconMarker {
 
     constructor({queryPoint, turnPoint, transitStop, transitLeg, ...params}) {
         let latitude;
@@ -55,8 +55,8 @@ export class TurnPointMarker extends MapMarker {
             this._image.paintable =
                 this._paintableFromIconName(turnPoint.iconName, 16);
         } else {
-            const color =
-                transitLeg?.color ? this._getRGBA(transitLeg.color) : null;
+            const color = transitLeg?.color ?
+                          Color.parseColorAsRGBA(transitLeg.color) : null;
 
             this._image.paintable =
                 this._paintableFromIconName('maps-point-end-symbolic',
@@ -65,13 +65,6 @@ export class TurnPointMarker extends MapMarker {
         }
     }
 
-    _getRGBA(color) {
-        return new Gdk.RGBA({ red: Color.parseColor(color, 0),
-                              green: Color.parseColor(color, 1),
-                              blue: Color.parseColor(color, 2),
-                              alpha: 1.0 });
-    }
-
     goTo() {
         this._mapView.map.go_to(this.latitude, this.longitude);
     }
